@media (min-width: 1300px) {
  .layui-container {
    width: 1250px
  }
}
@media (min-width: 1400px) {
  .layui-container {
    width: 1350px
  }
}
@media (min-width: 1500px) {
  .layui-container {
    width: 1450px
  }
}
@media (min-width: 1600px) {
  .layui-container {
    width: 1550px
  }
}
@media (max-width: 768px) {
  .pc {
    display: none !important;
  }
}
#header {
  margin-bottom: 1rem;
  background-color: #393D49;
  height: 61px;
}
.jumbotron {
  position: relative;
  overflow: hidden;
  text-align: center;
  border: 1px dashed #ff9163;
  padding: 40px 0 30px;
}
#upload-box {
  width: 100%;
  background: #fafafa;
  padding: 20px 0;
  margin-bottom: 10px;
}
.hidden {
  display: none
}
body {
  font: 15px Helvetica Neue,Helvetica,Tahoma,Arial,sans-serif;
  color: #333;
}
th,td {
  white-space: nowrap !important;
  vertical-align: middle !important;
  padding: .5rem 1rem !important;
  text-align: center !important;
  min-height: 24px !important;
  line-height: 24px !important;
}
img, video {
  max-width: 100% !important
}
a {
  color: #888;
}
a:hover {
  color: #5872f7;
}
p{
  font-size: 15px;
  line-height: 28px;
}
.filelist {
  table-layout: fixed;
}
.arrow-down {
  content: '';
  width: 0;
  height: 0;
  border-style: solid dashed dashed;
  border-color: #fff transparent transparent;
  overflow: hidden;
  cursor: pointer;
  transition: all .2s;
  -webkit-transition: all .2s;
  position: absolute;
  top: 50%;
  margin-left: 6px;
  margin-top: -3px;
  border-width: 6px;
  border-top-color: rgba(128, 102, 102, 0.7);
}
.arrow-down.arrow-up {
      margin-top: -9px;
    border-style: dashed dashed solid;
    border-color: transparent transparent rgba(128, 102, 102, 0.7);
}
input[type=file] {
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  opacity: 0;
  filter: alpha(opacity=0);
  cursor: pointer;
}
.batch-upload input[type=file]{
  display: inline-block;
  left: 32px;
  width: 32px;
}
#masonry {
  margin-top: 10px;
  margin-bottom: 10px;
}
.crumbs {
  padding: 10px;
  background: #f9f9f9;
  font-weight: 900;
}
.crumbs a i {
  font-size: 16px;
  margin-right: 5px;
}
.layui-breadcrumb>* {
  font-size: 14px;
}
.layui-icon:hover {
    color: #63ab5e;
}
.layui-card {
  background-color: #f9f9f9;
  text-align: center;
}
.list-name {
  white-space: pre-wrap;
  word-wrap: break-word;
}
.table-name {
  white-space: pre-wrap;
  word-wrap: break-word;
  -webkit-box-orient: vertical;
  -webkit-line-clamp: 1;
  display: inline-block;
  width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.layui-laypage {
  display: block;
}
.layui-table {
  color: #87888a;
}
.layui-table tbody tr:hover {
  background: #f8f8f8;
}
.layui-table tbody tr.selected {
  background-color: #f2f2f2 !important;
}
.layui-table td, .layui-table th {
  font-size: 14px;
}
.layui-table .icon {
  width: 20px;
  height: 20px;
}
.layui-tree {
  line-height: 22px;
  padding: 10px;
}
.layui-tree-branch {
  display: none
}
.layui-tree-branch+cite {
  color: #e20808;
  font-weight: 900;
}
.layui-btn .layui-icon {
  margin-right: 0
}
.layui-breadcrumb span[lay-separator]{
  margin: 0 5px;
}
.layui-btn-xs {
  height: 25px;
  line-height: 25px;
  padding: 0 8px;
}
.layui-btn-menu {
  background: #fff;
  padding: 0;
  border-radius: 20px;
  display: inline-block;
  margin-left: 5px;
  bottom: 3px;
}
.layui-btn-menu .btn-menu {
  width: 15px;
  line-height: 25px;
  color: #555 !important;
  padding: 0 8px !important;
}
.logo+.layui-nav {
  margin-left: 80px;
}
.layui-nav li a i {
  margin-right: 5px;
}
.layui-nav .layui-form {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  line-height: 60px;
}
.layui-nav .layui-input {
  margin-left: 20px;
  width: 300px;
  height: 30px;
  line-height: 30px;
  border: 1px solid #5d872f;
  font-size: 16px;
  background: #333640;
  border-radius: 20px;
}
.layui-btn-menu .layui-this:after, .layui-nav-bar, .layui-nav-tree .layui-nav-itemed:after {
  height: 0 !important;
  background-color: #fff !important;
}
.layui-btn-menu .layui-nav-child dd.layui-this, .layui-btn-menu .layui-nav-child dd.layui-this a {
  color: #333;
  background-color: #eee !important;
}
.layui-btn-menu span.layui-nav-more {
  display: none !important;
}
.layui-btn-menu .layui-nav-child {
  z-index: 9999 !important;
  top: 34px;
  left: -30px;
  background: #fff;
}
.layui-btn-menu .layui-nav-child a {
  font-size: 13px;
  line-height: 30px;
}
.layui-btn+.layui-btn {
  margin-left: 5px;
}
.logo {
  color: rgba(255,255,255,.7) !important;
  font-size: 20px;
  line-height: 60px;
  position: absolute;
  z-index: 1000;
  padding: 0 10px;
}
.logo:hover {
  color: #fff !important;
}
.nav-right {
  position: absolute;
  right: 0;
  top: 0;
}
.signin, .signup, .reset{
  max-width: 400px;
  margin: 20px auto;
}
.signin .reset {
  float: right;
  margin-top: 10px;
}
.weixin-login {
  background-color: #44b549;
  background-image: -webkit-gradient(linear,left top,left bottom,color-stop(0,#44b549),to(#44b549));
  background-image: linear-gradient(to bottom,#44b549 0,#44b549 100%);
  border-color: #44b549;
}
.input-group input {
  display: inline-block;
  width: 320px;
}


@font-face {font-family: "iconfont";
  src: url('iconfont.eot?t=1604933705048'); /* IE9 */
  src: url('iconfont.eot?t=1604933705048#iefix') format('embedded-opentype'), /* IE6-IE8 */
  url('data:application/x-font-woff2;charset=utf-8;base64,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') format('woff2'),
  url('iconfont.woff?t=1604933705048') format('woff'),
  url('iconfont.ttf?t=1604933705048') format('truetype'), /* chrome, firefox, opera, Safari, Android, iOS 4.2+ */
  url('iconfont.svg?t=1604933705048#iconfont') format('svg'); /* iOS 4.1- */
}

.iconfont {
  font-family: "iconfont" !important;
  font-size: 16px;
  font-style: normal;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.icon-table:before {
  content: "\ead4";
}

.icon-copy:before {
  content: "\e616";
}

.icon-delete:before {
  content: "\e650";
}

.icon-setting:before {
  content: "\e617";
}

.icon-closeeye:before {
  content: "\e64a";
}

.icon-eye:before {
  content: "\e823";
}

.icon-folder:before {
  content: "\e6aa";
}

.icon-list:before {
  content: "\e68e";
}

.icon-clouddownload:before {
  content: "\e611";
}
